(panes)=

# Panes

- Contain [pseudoterminal]s ([pty(4)][pty(4)])
- Exist inside {ref}`Windows`
- Identified by `%`, e.g. `%313`

[pseudoterminal]: https://en.wikipedia.org/wiki/Pseudoterminal
[pty(4)]: https://www.freebsd.org/cgi/man.cgi?query=pty&sektion=4

```{eval-rst}
.. autoclass:: libtmux.Pane
    :members:
    :inherited-members:
    :private-members:
    :show-inheritance:
    :member-order: bysource
```
